==> haskell-jwt-0.7.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-jwt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jwt
version: 0.7.2
id: jwt-0.7.2-3mw1wmBLULJ9bsqanrNo8g
key: jwt-0.7.2-3mw1wmBLULJ9bsqanrNo8g
license: MIT
maintainer: stefan@saasen.me
homepage: https://bitbucket.org/ssaasen/haskell-jwt
synopsis: JSON Web Token (JWT) decoding and encoding
description:
    JSON Web Token (JWT) is a compact URL-safe means of representing claims to be transferred between two parties.
    .
    To get started, see the documentation for the "Web.JWT" module.
category: Web
author: Stefan Saasen
exposed: True
exposed-modules:
    Web.JWT
hidden-modules: Data.Text.Extended Data.ByteString.Extended
abi: a60e50b1044de27f3240b33b1c07a2a2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/jwt-0.7.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/jwt-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/jwt-0.7.2
hs-libraries: HSjwt-0.7.2-3mw1wmBLULJ9bsqanrNo8g
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.24-8CPx71TTAGL9kKBh2LMKdw
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    memory-0.14.6-8f3xLObLA3p67pVexclvQP
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-jwt/html/jwt.haddock
haddock-html: /usr/share/doc/haskell-jwt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jwt-0.7.2-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-jwt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jwt
version: 0.7.2
id: jwt-0.7.2-99Tkdg52tLN6NtxntfghUh
key: jwt-0.7.2-99Tkdg52tLN6NtxntfghUh
license: MIT
maintainer: stefan@saasen.me
homepage: https://bitbucket.org/ssaasen/haskell-jwt
synopsis: JSON Web Token (JWT) decoding and encoding
description:
    JSON Web Token (JWT) is a compact URL-safe means of representing claims to be transferred between two parties.
    .
    To get started, see the documentation for the "Web.JWT" module.
category: Web
author: Stefan Saasen
exposed: True
exposed-modules:
    Web.JWT
hidden-modules: Data.Text.Extended Data.ByteString.Extended
abi: 008a7392eabfd48573f3527d52fd1d3d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/jwt-0.7.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/jwt-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/jwt-0.7.2
hs-libraries: HSjwt-0.7.2-99Tkdg52tLN6NtxntfghUh
depends:
    aeson-1.2.1.0-LtwtJj4trOg6E4DiroefXf base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.24-8CPx71TTAGL9kKBh2LMKdw
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    memory-0.14.6-8f3xLObLA3p67pVexclvQP
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-jwt/html/jwt.haddock
haddock-html: /usr/share/doc/haskell-jwt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
